@@ -1,3 +1,7 @@
 # SPDX-FileCopyrightText: 2023 Maxwell G <gotmax@e.email>
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
+
+from __future__ import annotations
+
+__version__ = "0.5.0"
