@@ -8,6 +8,7 @@ import abc
 import argparse
 import logging
 from collections.abc import Callable
+from pathlib import Path
 from typing import Any
 
 fmt = "{levelname}:{name}: {message}"
@@ -28,11 +29,11 @@ class Command(abc.ABC):
     @abc.abstractmethod
     def make_parser(
         cls, parser_func: Callable = argparse.ArgumentParser, standalone=False, **kwargs
-    ):
+    ) -> argparse.ArgumentParser:
         ...
 
     @abc.abstractmethod
-    def run(self) -> int:
+    def run(self) -> str | int:
         ...
 
     @property
@@ -40,3 +41,11 @@ class Command(abc.ABC):
         if getattr(self, "_cleanup", None) is None:
             self._cleanup = []
         return self._cleanup
+
+    def _v_specpath(self, path: Path | None = None) -> Path:
+        if not path:
+            pwd = Path.cwd()
+            path = Path(pwd.name + ".spec")
+        if not path.is_file() or path.suffix != ".spec":
+            raise InvalidArgumentError(f"{path} must exist an end with '.spec'")
+        return path
