@@ -20,6 +20,7 @@ from typing import TYPE_CHECKING
 import pygit2
 import specfile as sfile
 
+from .._util import escape_percentage
 from .base import Command, InvalidArgumentError
 
 if TYPE_CHECKING:
@@ -48,7 +49,7 @@ class GitLogEntry:
         # --allow-empty-message
         if not message:
             message = ["bump"]
-        return ["- " + message[0]]
+        return ["- " + escape_percentage(message[0])]
 
     @property
     def author(self) -> str:
@@ -60,7 +61,7 @@ class GitLogEntry:
         timestamp = dt.datetime.fromtimestamp(
             self.commit.commit_time, tz=dt.timezone.utc
         )
-        return dt.date(timestamp.year, timestamp.month, timestamp.day)
+        return timestamp.date()
 
     @property
     def version(self) -> str:
@@ -142,14 +143,6 @@ class DevEntries(Command):
         parser.add_argument("-A", "--archive", action="store_true")
         return parser
 
-    def _v_specpath(self, path: Path | None = None) -> Path:
-        if not path:
-            pwd = Path.cwd()
-            path = pwd.joinpath(pwd.name + ".spec")
-        if not path.is_file() or path.suffix != ".spec":
-            raise InvalidArgumentError(f"{path} must exist an end with '.spec'")
-        return path
-
     def _guess_last_ref(self, baseversion: str | None, pre: str | None) -> None:
         self.pre = bool(pre)
         if not baseversion:
